import random


def main():
    printIntro()
    probA, probB, n = getInputs()
    winsA, winsB = simNGames(probA, probB, n)
    printSummary(winsA, winsB)


def printIntro():
    print("Welcome to RacquetBall Simulator 3000!")


def getInputs():
    probA = int(input("Probability of A winning: "))
    probB = int(input("Probability of B winning: "))
    n = int(input("Number of games: "))
    return probA, probB, n


def simNGames(probA, probB, n):
    """Simulates N games of racquetball.

    :param probA: (0-100) probability that A wins
    :param probB: (0-100) probability that B wins
    :param n: number of games
    :return: total wins of A, total wins of B
    """
    winsA, winsB = 0, 0
    for i in range(n):
        scoreA, scoreB = simOneGame(probA, probB)
        if scoreA > scoreB:
            winsA += 1
        else:
            winsB += 1
    return winsA, winsB


def simOneGame(probA, probB):
    scoreA, scoreB = 0, 0
    current = "A"
    while not gameOver(scoreA, scoreB):
        if current == "A":
            if random.randint(1, 100) <= probA:
                scoreA += 1
            else:
                current = "B"
        else:
            if random.randint(1, 100) <= probB:
                scoreB += 1
            else:
                current = "A"
    return scoreA, scoreB


def gameOver(scoreA, scoreB):
    larger = max(scoreA, scoreB)
    smaller = min(scoreA, scoreB)
    return larger >= 15 and larger >= smaller + 2


def printSummary(winsA, winsB):
    n = winsA + winsB
    print("No. of games played:", n)
    print("A's win rate:", 100 * winsA // n)
    print("B's win rate:", 100 * winsB // n)


main()
